Type Alias ezno_parser::Span

source ·
pub type Span = BaseSpan<()>;

Aliased Type

struct Span {
    pub start: u32,
    pub end: u32,
    pub source: (),
}

Fields

start: u32end: u32source: ()

Implementations

source

impl BaseSpan<()>

source

pub const NULL_SPAN: BaseSpan<()> = _

TODO explain use cases

source

pub fn is_null(&self) -> bool

TODO explain use cases

source

pub fn is_adjacent_to(&self, other: impl Into<Start>) -> bool

Returns whether the end of self is the start of other

source

pub fn union(&self, end: impl Into<End>) -> BaseSpan<()>

Returns a new Span which starts at the start of self a ends at the end of other

source

pub fn get_end(&self) -> End

source

pub fn get_start(&self) -> Start

source

pub fn with_source(self, source: SourceId) -> BaseSpan<SourceId>