Type Alias ezno_parser::Span
source · pub type Span = BaseSpan<()>;Aliased Type
struct Span {
pub start: u32,
pub end: u32,
pub source: (),
}Fields
start: u32end: u32source: ()Implementations
sourceimpl BaseSpan<()>
impl BaseSpan<()>
sourcepub fn is_adjacent_to(&self, other: impl Into<Start>) -> bool
pub fn is_adjacent_to(&self, other: impl Into<Start>) -> bool
Returns whether the end of self is the start of other
sourcepub fn union(&self, end: impl Into<End>) -> BaseSpan<()>
pub fn union(&self, end: impl Into<End>) -> BaseSpan<()>
Returns a new Span which starts at the start of self a ends at the end of other
pub fn get_end(&self) -> End
pub fn get_start(&self) -> Start
pub fn with_source(self, source: SourceId) -> BaseSpan<SourceId>